@@ -1,4 +1,3 @@
-from threading import local
 import traceback
 from function_scheduling_distributed_framework import fsdf_background_scheduler, task_deco, patch_frame_config, get_publisher, BrokerEnum
 from function_scheduling_distributed_framework.consumers.base_consumer import ExceptionForRequeue
@@ -80,7 +79,7 @@ async def file_transfer_put(url, bucket, bucket_name, ttl):
     with cache_engine.lock(key, ttl=30) as lock:
         if lock:
             try:
-                if cache_engine.get_cache(key, return_obj=False) is not None:
+                if await cache_engine.get_cache_async(key, return_obj=False) is not None:
                     return
                 
                 file_path = os.path.join(cache_path, '{}_{}'.format(bucket, bucket_name))
@@ -126,50 +125,34 @@ async def file_transfer_put(url, bucket, bucket_name, ttl):
                     }, expired=60)
 
 
-@task_deco('fs_get', function_timeout=60, concurrent_mode=4, broker_kind=BrokerEnum.NSQ, specify_async_loop=asyncio.get_event_loop())
+@task_deco('fs_get', function_timeout=60, concurrent_mode=4, broker_kind=BrokerEnum.NSQ)
 async def file_transfer_get(bucket, bucket_name, refresh='no'):
     try:
         task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
-        if refresh == 'no':
-            remote_state = cache_engine.get_cache(task_id)
-            if remote_state is not None:
-                ret = remote_state['ret']
-                if ret:
-                    print('remote has record->{}, ignored.'.format(task_id))
-                    return
-
-        with cache_engine.lock(task_id) as lock:
-            remote_state = cache_engine.get_cache(task_id)
-            if remote_state is not None:
-                ret = remote_state['ret']
-                if ret:
-                    print('remote has record->{}, ignored.'.format(task_id))
-                    return
-
-            file_path = os.path.join(cache_path, '{}_{}'.format(bucket, bucket_name))
-            if not os.path.isfile(file_path):
-                ret, e = minio.download_file(file_path, bucket, bucket_name)
-                if ret:
-                    file_path = e
-                else:
-                    cache_engine.cache(task_id, {
-                        'ret': False, 
-                        'err': e.message
-                    }, expired=60)
-                    return
-
-            ret, e = hmfs_client.put_to_cloud(file_path, bucket, bucket_name)
+        file_path = os.path.join(cache_path, '{}_{}'.format(bucket, bucket_name))
+        if not os.path.isfile(file_path):
+            ret, e = minio.download_file(file_path, bucket, bucket_name)
             if ret:
-                cache_engine.cache(task_id, {
-                    'ret': True,
-                    'url': e
-                }, expired=60 * 60 * 24 * 1)
-                print('upload success!!')
+                file_path = e
             else:
                 cache_engine.cache(task_id, {
                     'ret': False, 
-                    'err': e
+                    'err': e.message
                 }, expired=60)
+                return
+
+        ret, e = hmfs_client.put_to_cloud(file_path, bucket, bucket_name)
+        if ret:
+            cache_engine.cache(task_id, {
+                'ret': True,
+                'url': e
+            }, expired=60 * 60 * 24 * 1)
+            print('upload success!!')
+        else:
+            cache_engine.cache(task_id, {
+                'ret': False, 
+                'err': e
+            }, expired=60)
     except Exception as e:
         traceback.print_exc()
     
@@ -196,7 +179,7 @@ async def ttl_cleanup():
     if rows is not None:
         for r in rows:
             bucket, bucket_name = r['bucket'], r['bucket_name']
-            ret, e = minio.delete(bucket, bucket_name, 0)
+            ret, e = await minio.delete(bucket, bucket_name, 0)
             if ret:
                 affected_records += 1
                 print('removing file id: {} from db...'.format(r['id']))
