@@ -3,7 +3,6 @@ import redis
 import time
 import threading
 
-import coredis
 
 from redis.exceptions import LockError 
 from hamunafs.utils.singleton_wrapper import Singleton
@@ -265,6 +264,10 @@ class XRedis(Singleton):
         conn = self._get_connection()
         return conn.zscore(z_name, key)
 
+try:
+    import coredis
+except:
+    pass
 class XRedisAsync(Singleton):
     def __init__(self, host, password, port, db=0):
         if not self.need_init():
@@ -301,7 +304,7 @@ class XRedisAsync(Singleton):
             print('连接失败, 网络错误')
             return False
             
-    def __get_connection(self) -> coredis.StrictRedis:
+    def __get_connection(self):
         if hasattr(self, 'conn'):
             return self.conn
         return None
